TileOrientation

Enum TileOrientation 

#[repr(u8)]
pub enum TileOrientation { Default = 0, Rotate90 = 3, Rotate180 = 6, Rotate270 = 5, MirrorH = 4, MirrorHRotate90 = 1, MirrorHRotate180 = 2, MirrorHRotate270 = 7, }
The set of possible tile orientations. These represent all possible results of mirroring the tile horizontally and/or vertically, and/or rotation by 90 degree increments.

Rotation is measured counter-clockwise as elsewhere in Bevy.

The representation is a u8 value where the bits (from most significant to least significant), represent:

  • Bit 2: Mirroring the tile horizontally (left and right sides are swapped)
  • Bit 1: Mirroring the tile vertically (top and bottom are swapped)
  • Bit 0: Mirroring the tile diagonally (top-right and bottom-left corners are swapped)

The order in which the mirroring is performed matters - the tile is first mirrored horizontally (if specified), then vertically, then finally diagonally, in the UV coordinate system.

Note that different coordinate systems are used for UV mapping and Bevy world coordinates (e.g. in UV maps, the y component increases towards the bottom of the tile, in Bevy it increases towards the top). This means that the ordering in which the mirroring is applied differs in different coordinate systems.

The ordering of the enum starts from the default orientation (no rotation or mirroring), then we have successive 90 degree counter-clockwise rotations. Then we have a tile mirrored horizontally, and then the results of successive 90 degree counter-clockwise rotations of the mirrored tile.

The enum values can be easily converted to the format used for tile indices in Tiled maps, where bits 31, 30 and 29 correspond to bits 2, 1 and 0 of this enum’s values. So for a given enum value, we can just use value << 29 to produce the bits required in a Tiled index.

Variants



Default = 0



Rotate90 = 3



Rotate180 = 6



Rotate270 = 5



MirrorH = 4



MirrorHRotate90 = 1



MirrorHRotate180 = 2



MirrorHRotate270 = 7

Implementations

Source

impl TileOrientation

pub fn from_bools( mirror_h: bool, mirror_v: bool, mirror_d: bool, ) -> TileOrientation

Create a TileOrientation based on whether each mirror is applied

pub fn mirror_h(&self) -> bool

True if the tile is mirrored horizontally

pub fn mirror_v(&self) -> bool

True if the tile is mirrored vertically

pub fn mirror_d(&self) -> bool

True if the tile is mirrored diagonally

pub fn inverse(&self) -> TileOrientation

This method treats each TileOrientation as the transform from TileOrientation::Default to that orientation. Find the TileOrientation that when applied will undo the effect of this TileOrientation

pub fn apply_to_ivec2(&self, pos: &IVec2) -> IVec2

This method treats the TileOrientation as the transform from TileOrientation::Default to this orientation. Apply this transformation to an IVec2

pub fn and_then(&self, then: TileOrientation) -> TileOrientation

This method treats each TileOrientation as the transform from TileOrientation::Default to that orientation. Produce a TileOrientation that will give the same effect as applying this transform, then applying then.